@@ -4,15 +4,15 @@ from future.builtins import *
 
 from blockext import *
 
-
 import sphero
 
-__version__ = '0.2.1'
+__version__ = '0.2.3'
 
 class Sphero:
     def __init__(self):
         self.robot = sphero.Sphero()
         self.robot.connect()
+        self.robot.set_back_led_output(255)
         self.name = self.robot.get_bluetooth_info().name
         
     """def _is_connected(self):
@@ -45,8 +45,8 @@ class Sphero:
     def roll_sphero(self, power, heading):
         self.robot.roll(power*2.55, heading)
         
-    """def set_sphero_color(self, r, g, b):
-        self.robot.set_rgb(r,g,b)"""
+    def set_sphero_color(self, r, g, b):
+        self.robot.set_rgb(r,g,b)
     
 
 descriptor = Descriptor(
@@ -55,7 +55,8 @@ descriptor = Descriptor(
     blocks = [
         Block('roll_sphero', 'command', 'roll Sphero %n percent speed at %n degrees', defaults=[100,0]),
         Block('get_sphero_name', 'reporter', 'get Sphero name'),
-        Block('set_sphero_name', 'command', 'set Sphero name to %s', defaults=['Rob Orb'])
+        Block('set_sphero_name', 'command', 'set Sphero name to %s', defaults=['Rob Orb']),
+        Block('set_sphero_color', 'command', 'set Sphero color to R: %n G: %n B: %n')
         
     ]
 )
